==> auto-ui-2.4.55.tgz: package/es/modal/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import supportDarkMode from '../__utils/supportDarkMode';
import './style/index.scss';
var Modal = /** @class */ (function (_super) {
    __extends(Modal, _super);
    function Modal(props) {
        var _this = _super.call(this, props) || this;
        _this.onAnimationEnd = function () {
            if (_this.state.ani !== 'leave') {
                return;
            }
            _this.setState({
                ani: 'init',
                visible: false,
                noContent: _this.props.keepalive ? false : true,
            });
        };
        _this.state = {
            visible: false,
            ani: 'init',
            noContent: true,
        };
        return _this;
    }
    Modal.prototype.componentDidMount = function () {
        if (this.props.visible) {
            this.enter();
        }
    };
    Modal.prototype.UNSAFE_componentWillReceiveProps = function (nextProps) {
        if (!this.props.visible && nextProps.visible) {
            this.enter();
        }
        else if (this.props.visible && !nextProps.visible) {
            this.leave();
        }
    };
    Modal.prototype.render = function () {
        var _a = this.props, onMaskClick = _a.onMaskClick, height = _a.height, width = _a.width, visible = _a.visible, className = _a.className, addonTop = _a.addonTop, addonBottom = _a.addonBottom, keepalive = _a.keepalive, otherProps = __rest(_a, ["onMaskClick", "height", "width", "visible", "className", "addonTop", "addonBottom", "keepalive"]);
        var composeClassName = cn('x-modal', "x-modal--" + this.state.ani, {
            'x-app--support-dark-mode': this.state.supportDarkMode,
        }, className);
        var heightval = '';
        if (height) {
            if (typeof height === 'number') {
                heightval = String(height) + "%";
            }
            else {
                heightval = height;
            }
        }
        var widthval = '';
        if (width) {
            if (typeof width === 'number') {
                widthval = String(width) + "%";
            }
            else {
                widthval = width;
            }
        }
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, style: {
                display: this.state.visible ? '' : 'none',
            } }),
            React.createElement("div", { className: "x-modal__mask", onClick: onMaskClick }),
            addonTop,
            React.createElement("div", { className: "x-modal__inner", style: { height: heightval, width: widthval }, onAnimationEnd: this.onAnimationEnd }, !this.state.noContent && this.props.children),
            addonBottom));
    };
    Modal.prototype.enter = function () {
        var _this = this;
        this.setState({
            visible: true,
            noContent: false,
            supportDarkMode: supportDarkMode(),
        });
        setTimeout(function () {
            _this.setState({
                ani: 'enter',
            });
        });
        var focusdom = document.querySelector(':focus');
        var nodeName = (focusdom || {}).nodeName;
        if (focusdom && (nodeName === 'input' || nodeName === 'textarea')) {
            ;
            focusdom.blur();
        }
    };
    Modal.prototype.leave = function () {
        this.setState({
            ani: 'leave',
        });
    };
    return Modal;
}(React.PureComponent));
export default Modal;

==> auto-ui-2.4.63.tgz: package/es/modal/index.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import supportDarkMode from '../__utils/supportDarkMode';
import './style/index.scss';
var Modal = /** @class */ (function (_super) {
    __extends(Modal, _super);
    function Modal(props) {
        var _this = _super.call(this, props) || this;
        _this.onAnimationEnd = function () {
            if (_this.state.ani !== 'leave') {
                return;
            }
            _this.setState({
                ani: 'init',
                visible: false,
                noContent: _this.props.keepalive ? false : true,
            });
        };
        _this.state = {
            visible: false,
            ani: 'init',
            noContent: true,
        };
        return _this;
    }
    Modal.prototype.componentDidMount = function () {
        if (this.props.visible) {
            this.enter();
        }
    };
    Modal.prototype.UNSAFE_componentWillReceiveProps = function (nextProps) {
        if (!this.props.visible && nextProps.visible) {
            this.enter();
        }
        else if (this.props.visible && !nextProps.visible) {
            this.leave();
        }
    };
    Modal.prototype.render = function () {
        var _a = this.props, onMaskClick = _a.onMaskClick, height = _a.height, width = _a.width, visible = _a.visible, className = _a.className, addonTop = _a.addonTop, addonBottom = _a.addonBottom, keepalive = _a.keepalive, otherProps = __rest(_a, ["onMaskClick", "height", "width", "visible", "className", "addonTop", "addonBottom", "keepalive"]);
        var composeClassName = cn('x-modal', "x-modal--" + this.state.ani, {
            'x-app--support-dark-mode': this.state.supportDarkMode,
        }, className);
        var heightval = '';
        if (height) {
            if (typeof height === 'number') {
                heightval = String(height) + "%";
            }
            else {
                heightval = height;
            }
        }
        var widthval = '';
        if (width) {
            if (typeof width === 'number') {
                widthval = String(width) + "%";
            }
            else {
                widthval = width;
            }
        }
        return (React.createElement("div", __assign({}, otherProps, { className: composeClassName, style: {
                display: this.state.visible ? '' : 'none',
            } }),
            React.createElement("div", { className: "x-modal__mask", onClick: onMaskClick }),
            addonTop,
            React.createElement("div", { className: "x-modal__inner", style: { height: heightval, width: widthval }, onAnimationEnd: this.onAnimationEnd }, !this.state.noContent && this.props.children),
            addonBottom));
    };
    Modal.prototype.enter = function () {
        var _this = this;
        this.setState({
            visible: true,
            noContent: false,
            supportDarkMode: supportDarkMode(),
        });
        setTimeout(function () {
            _this.setState({
                ani: 'enter',
            });
        });
        var focusdom = document.querySelector(':focus');
        var nodeName = (focusdom || {}).nodeName;
        if (focusdom && (nodeName === 'input' || nodeName === 'textarea')) {
            ;
            focusdom.blur();
        }
    };
    Modal.prototype.leave = function () {
        this.setState({
            ani: 'leave',
        });
    };
    return Modal;
}(React.PureComponent));
export default Modal;
